import java.util.Date;
import java.util.GregorianCalendar;

/**
 * Класс, инкапсулирующий информацию о сотруднике
 * */
public class Employee {
    private String name;
    private double salary;
    private Date hireDay;

    /**
     * Конструктор класса
     * @param name имя сотрудника
     * @param salary зарплата сотрудника
     * @param hireDay дата начала работы сотрудника
     * */
    public Employee(String name, double salary, Date hireDay) {
        this.name = name;
        this.salary = salary;
        this.hireDay = hireDay;
    }

    /**
     * Конструктор класса
     * @param name имя сотрудника
     * @param salary зарплата сотрудника
     * @param year год начала работы сотрудника
     * @param month месяц начала работы сотрудника
     * @param day день начала работы сотрудника
     * */
    public Employee(String name, double salary, int year, int month, int day) {
        this.name = name;
        this.salary = salary;
        GregorianCalendar calendar = new GregorianCalendar(year, month - 1, day);
        this.hireDay = calendar.getTime();
    }

    /**
     * Метод для получения имени сотрудника
     * @return имя сотрудника
     * */
    public String getName() {
        return name;
    }

    /**
     * Метод для получения зарплаты сотрудника
     * @return зарплата сотрудника
     * */
    public double getSalary() {
        return salary;
    }

    /**
     * Метод для получения даты приема на работу сотрудника
     * @return дата приема на работу сотрудника
     * */
    public Date getHireDay() {
        return hireDay;
    }

    /**
     * Метод для изменения зарплаты на заданное количество процентов
     * @param byPercent количество процентов, на которое будет изменена зарплата сотрудника
     * */
    public void raiseSalary(double byPercent) {
        double raise = salary * byPercent / 100;
        this.salary += raise;
    }

    /**
     * Переопределенный метод toString для вывода информации о сотруднике
     * @return информация о сотруднике
     * */
    @Override
    public String toString() {
        return  "name = " + name + ", salary = " + salary +
                ", hireDay = " + hireDay;
    }
}