/**
 * Класс, инкопсулирующий информацию о менеджере. Данный класс является наследником класса Employee.
 * В классе Manager дополнительно хранится сумма премии
 * @see Employee
 * */
public class Manager extends Employee {
    /**
     * Размер премии
     * */
    private double bonus;

    /**
     * Конструктор класса Manager. Переопределяет конструктор класса Employee
     * @param name имя сотрудника
     * @param salary зарплата сотрудника
     * @param year год начала работы сотрудника
     * @param month месяц начала работы сотрудника
     * @param day день начала работы сотрудника
     * */
    public Manager(String name, double salary, int year, int month, int day) {
        super(name, salary, year, month, day);
        bonus = 0;
    }

    /**
     * Функция для установки размера премии
     * @param bonus размер премии
     * */
    public void setBonus(double bonus) {
        this.bonus = bonus;
    }

    /**
     * Функция для получения размера премии менеджера
     * @return размер премии
     * */
    public double getBonus() {
        return bonus;
    }

    /**
     * Функция для получения заплаты менеджера с учетом премии
     * @return зарплата менеджера
     * */
    @Override
    public double getSalary() {
        double baseSalary = super.getSalary();
        return baseSalary + bonus;
    }

    /**
     * Переопределенный метод toString для вывода информации о менеджере
     * @return информация о менеджере
     * */
    @Override
    public String toString() {
        return "name = " + getName() + ", salary = " + getSalary() +
                ", hireDay = " + getHireDay();
    }
}
